{glossary-link term="hello"}{glossary-link end}

The most precise way of giving a set of instructions is in the form of a {glossary-link term="algorithm" reference-text="computer program"}program{glossary-link end}, which is a specific implementation of an algorithm, written in a specific programming language, with a very specific result for any particular input.

Because algorithms exist even if they aren't turned in to programs, we won't need to look at programs at all for this topic, unless you particularly want to.

{glossary-link term="algorithm" reference-text="algorithm cost"}{glossary-link end}

### Algorithm cost

They also happen to be great for illustrating some of the key concepts that arise with algorithms.

{glossary-link term="algorithm" reference-text="searching algorithms"}{glossary-link end}

## Searching

{panel end}

{glossary-link term="algorithm" reference-text="sorting algorithms"}{glossary-link end}
